from setuptools import setup

setup(
    name='OIDC-package-packagingCon23',
    version="1.0.0",
    description='OIDC-package-packagingCon23',
    long_description="OIDC-package-packagingCon23",
    long_description_content_type='text/markdown',
)